<?php

App::uses('EvAddressBookAppController', 'EvAddressBook.Controller');

class AddressBookController extends EvAddressBookAppController {

	public function beforeFilter() {
		parent::beforeFilter();

		$this->AddressManager = $this->loadComponent('EvAddressBook.AddressManager');
		$this->helpers[] = 'EvAddressBook.AddressBook';
	}

	/**
	 * list addresses
	 */
	public function index() {
		$this->set(
			'addressBook',
			$this->AddressManager->getAddresses(
				EvClassRegistry::init('EvAddressBook.Address'),
				'EvCore.User',
				$this->Auth->user('User.id')
			)
		);

		$this->set('titleForLayout', 'Your Address Book');

		$this->view = 'EvAddressBook.AddressBook/index';
	}

	/**
	 * add new address
	 */
	public function add() {
		if ($this->request->is('post') && ! empty($this->request->data)) {
			$AddressModel = EvClassRegistry::init('EvAddressBook.Address');

			$result = $this->AddressManager->add(
				$AddressModel,
				'EvCore.User',
				$this->Auth->user('User.id')
			);

			// if successful select the address
			if ($result['result'] === true) {
				$this->Flash->success($result['data']['message']);

				$route = $this->Routable->getItemRoute('EvAddressBook', 'Address');
				$this->redirect($route);

			} else {
				$this->Flash->fail($result['data']['errors']);
			}
		}

		$CountryModel = EvClassRegistry::init('EvCountry.Country');
		$this->set(
			'countries',
			$CountryModel->getForDropdown()
		);

		$this->view = 'EvAddressBook.AddressBook/add';
		$this->set('titleForLayout', 'Add Address');
	}

	/**
	 * delete address
	 */
	public function delete($id) {
		$AddressModel = EvClassRegistry::init('EvAddressBook.Address');

		$check = $this->AddressManager->addressBelongsToUser($AddressModel, $id, $this->Auth->user('User.id'));
		if ($check['result'] === true) {

			if ($AddressModel->delete($id)) {
				$this->Flash->success(
					'Address has been deleted'
				);
			} else {
				$this->Flash->fail(
					'There was a problem deleting the address, please try again.'
				);
			}
		} else {
			$this->Flash->fail(
				'Address deletion failed, you do not have permission to delete this address.'
			);
		}

		$route = $this->Routable->getItemRoute('EvAddressBook', 'Address');
		$this->redirect($route);
	}
}
